@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@ class __libcore Textbox: public BaseGraphicObject{
 
 		double font_size;
 
+		double text_width;
+
 		//! \brief Color used to draw the text
 		QColor text_color;
 
@@ -53,6 +55,8 @@ class __libcore Textbox: public BaseGraphicObject{
 		 method used to get the current text */
 		Textbox();
 
+		virtual ~Textbox(){}
+
 		//! \brief Sets the attributes of the text
 		void setTextAttribute(TextAttrib attrib, bool value);
 
@@ -61,6 +65,8 @@ class __libcore Textbox: public BaseGraphicObject{
 
 		void setFontSize(double size);
 
+		void setTextWidth(double width);
+
 		/*! \brief Since textboxes doesn't has SQL code definition this method will return a empty
 		definition whenever the user try to generate a SQL for this object. */
 		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
@@ -72,6 +78,8 @@ class __libcore Textbox: public BaseGraphicObject{
 
 		double getFontSize();
 
+		double getTextWidth();
+
 		virtual void setZValue(int z_value);
 
 		//! \brief Copies the attributes between textboxes
